from setuptools import setup

setup(
    name='hicon',
    version='0.1.0',    
    description='Create, use, edit and manage hierarchical configurations files with Python.',
    url='https://github.com/gt-on-1234/hicon',
    author='Oscar Nuki',
    # author_email='shudson@anl.gov',
    license='MIT',
    packages=['hicon'],
    install_requires=[],
    classifiers=[],
)